==> haskell-status-notifier-item-0.3.1.0-287-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-status-notifier-item.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 status-notifier-item
version:              0.3.1.0
visibility:           public
id:                   status-notifier-item-0.3.1.0-KBKIVch10VOA04RVuTLVGR
key:                  status-notifier-item-0.3.1.0-KBKIVch10VOA04RVuTLVGR
license:              BSD-3-Clause
copyright:            2018 Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/status-notifier-item#readme
synopsis:
    A wrapper over the StatusNotifierItem/libappindicator dbus specification

description:
    Please see the README on Github at <https://github.com/IvanMalison/status-notifier-item#readme>

category:             Desktop
abi:                  d720408a48241e9dbb16be7702ff6e60
exposed:              True
exposed-modules:
    StatusNotifier.Host.Service StatusNotifier.Item.Client
    StatusNotifier.Item.Service StatusNotifier.TH StatusNotifier.Util
    StatusNotifier.Watcher.Client StatusNotifier.Watcher.Constants
    StatusNotifier.Watcher.Service StatusNotifier.Watcher.Signals

hidden-modules:       Paths_status_notifier_item
import-dirs:          /usr/lib/ghc-9.4.8/site-local/status-notifier-item-0.3.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/status-notifier-item-0.3.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/status-notifier-item-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-status-notifier-item
hs-libraries:         HSstatus-notifier-item-0.3.1.0-KBKIVch10VOA04RVuTLVGR
depends:
    base-4.17.2.1 byte-order-0.1.3.1-A0fGkTSjlsN4lVEvwTkAEK
    bytestring-0.11.5.3
    bytestring-to-vector-0.3.0.1-I9HFPHQUUQP9fjpoLvQb1q
    containers-0.6.7 dbus-1.3.3-DxwQecE0J4QHGHdMDtxYGB filepath-1.4.2.2
    hslogger-1.3.2.0-5UzjE3rtE0cIibzskwqOPp
    lens-5.3.1-57CGCDOUfQCLkJSlnZcVUR template-haskell-2.19.0.0
    text-2.0.2 transformers-0.5.6.2
    vector-0.13.2.0-AtXaKVcIvtCInBZOrzSe57

haddock-interfaces:
    /usr/share/doc/haskell-status-notifier-item/html/status-notifier-item.haddock

haddock-html:         /usr/share/doc/haskell-status-notifier-item/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-status-notifier-item-0.3.1.0-308-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-status-notifier-item.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 status-notifier-item
version:              0.3.1.0
visibility:           public
id:                   status-notifier-item-0.3.1.0-1pnsIW7W5tH3KV6qz5Fumr
key:                  status-notifier-item-0.3.1.0-1pnsIW7W5tH3KV6qz5Fumr
license:              BSD-3-Clause
copyright:            2018 Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/status-notifier-item#readme
synopsis:
    A wrapper over the StatusNotifierItem/libappindicator dbus specification

description:
    Please see the README on Github at <https://github.com/IvanMalison/status-notifier-item#readme>

category:             Desktop
abi:                  5b6b58c1c13d522f569489f17780d085
exposed:              True
exposed-modules:
    StatusNotifier.Host.Service StatusNotifier.Item.Client
    StatusNotifier.Item.Service StatusNotifier.TH StatusNotifier.Util
    StatusNotifier.Watcher.Client StatusNotifier.Watcher.Constants
    StatusNotifier.Watcher.Service StatusNotifier.Watcher.Signals

hidden-modules:       Paths_status_notifier_item
import-dirs:          /usr/lib/ghc-9.4.8/site-local/status-notifier-item-0.3.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/status-notifier-item-0.3.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/status-notifier-item-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-status-notifier-item
hs-libraries:         HSstatus-notifier-item-0.3.1.0-1pnsIW7W5tH3KV6qz5Fumr
depends:
    base-4.17.2.1 byte-order-0.1.3.1-J24g9yQP3QWApeTxNQTq8i
    bytestring-0.11.5.3
    bytestring-to-vector-0.3.0.1-FP9annBtzhQB0ZNnC54vWE
    containers-0.6.7 dbus-1.3.3-LpDQHaNyiML1MRcclv9sum filepath-1.4.2.2
    hslogger-1.3.2.0-20ZBQm4ZKyVCpCr1LdKap5
    lens-5.3.3-1zYcQilqoBK5EhYwkXjOnb template-haskell-2.19.0.0
    text-2.0.2 transformers-0.5.6.2
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS

haddock-interfaces:
    /usr/share/doc/haskell-status-notifier-item/html/status-notifier-item.haddock

haddock-html:         /usr/share/doc/haskell-status-notifier-item/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
